==> typescript-node-scripts-0.1.4.tgz: package/lib/webpack.config.dev.js <==
const { resolve } = require('path')
const paths = require('./paths')
const nodeExternals = require('webpack-node-externals')
const tsconfigPathsPlugin = require('tsconfig-paths-webpack-plugin')
const formatTsLoaderMessages = require('./formatTsLoaderMessages')
const { tslintShouldEmitErrors } = require('./tsLintHelper')

module.exports = {
    mode: 'development',
    entry: paths.appIndexJs,
    target: 'node',
    externals: [nodeExternals()],
    output: {
        path: paths.appDevBundlePath,
        filename: 'bundle.js',
        libraryTarget: 'commonjs'
    },
    resolve: {
        extensions: ['.ts', '.tsx', '.js', '.json'],
        plugins: [
            new tsconfigPathsPlugin({
                configFile: paths.appTsConfig
            })
        ]
    },
    module: {
        rules: [
            {
                test: /\.tsx?$/,
                enforce: 'pre',
                use: [
                    {
                        loader: require.resolve('tslint-loader'),
                        options: {
                            emitErrors: tslintShouldEmitErrors(paths.appTsLint),
                            tsConfigFile: paths.appTsConfig,
                            configFile: paths.appTsLint,
                            formatter: 'lintTable',
                            formattersDirectory: __dirname + '/formatters/'
                        }
                    }
                ]
            },
            {
                test: /\.tsx?$/,
                include: paths.appSrc,
                loader: require.resolve('ts-loader'),
                options: {
                    colors: true,
                    errorFormatter: formatTsLoaderMessages
                }
            }
        ]
    },
    optimization: {
        nodeEnv: false
    },
    node: {
        __dirname: false,
        __filename: false
    },
    performance: {
        hints: false
    }
}

==> typescript-node-scripts-0.1.10.tgz: package/lib/webpack.config.dev.js <==
const paths = require('./paths')
const nodeExternals = require('webpack-node-externals')
const tsconfigPathsPlugin = require('tsconfig-paths-webpack-plugin')
const formatTsLoaderMessages = require('./formatTsLoaderMessages')
const { tslintShouldEmitErrors } = require('./tsLintHelper')

module.exports = {
    mode: 'development',
    entry: paths.appIndexJs,
    target: 'node',
    externals: [nodeExternals()],
    output: {
        path: paths.appDevBundlePath,
        filename: 'bundle.js',
        libraryTarget: 'commonjs',
    },
    resolve: {
        extensions: ['.ts', '.tsx', '.js', '.json'],
        plugins: [
            new tsconfigPathsPlugin({
                configFile: paths.appTsConfig,
            }),
        ],
    },
    module: {
        rules: [
            {
                test: /\.tsx?$/,
                enforce: 'pre',
                use: [
                    {
                        loader: require.resolve('tslint-loader'),
                        options: {
                            emitErrors: tslintShouldEmitErrors(paths.appTsLint),
                            tsConfigFile: paths.appTsConfig,
                            configFile: paths.appTsLint,
                            formatter: 'lintTable',
                            formattersDirectory: __dirname + '/formatters/',
                        },
                    },
                ],
            },
            {
                test: /\.tsx?$/,
                include: paths.appSrc,
                loader: require.resolve('ts-loader'),
                options: {
                    colors: true,
                    errorFormatter: formatTsLoaderMessages,
                },
            },
        ],
    },
    optimization: {
        nodeEnv: false,
    },
    node: {
        __dirname: false,
        __filename: false,
    },
    performance: {
        hints: false,
    },
}
